==> rutorrent-3.9.tar.gz: ruTorrent-3.9/plugins/rss/lang/pl.js <==
﻿/*
 * PLUGIN RSS
 *
 * Polish language file.
 *
 * Author: Dare (piczok@gmail.com)
 */

 theUILang.addRSS			= "Dodaj kanał";
 theUILang.feedURL			= "Adres kanału";
 theUILang.alias			= "Nazwa";
 theUILang.rssAuto			= "Automatycznie pobieraj elementy publikowane na kanale";
 theUILang.allFeeds			= "Wszystkie";
 theUILang.incorrectURL 		= "Proszę, podaj poprawny adres kanału."
 theUILang.cantFetchRSS 		= "Błąd wczytywania kanału.";
 theUILang.rssAlreadyExist		= "Kanał już istnieje.";
 theUILang.rssDontExist 		= "Kanał nie istnieje.";
 theUILang.rssCantLoadTorrent		= "Błąd pobierania torrenta.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Pobrany";
 theUILang.rssMenuLoad			= "Pobierz";
 theUILang.rssMenuOpen			= "Otwórz w przeglądarce";
 theUILang.rssMenuClearHistory		= "Wyczyść historię";
 theUILang.rssMenuAddToFilter		= "Dodaj do ulubionych";
 theUILang.rssMenuManager		= "Menedżer RSS";
 theUILang.rssMenuRefresh		= "Odśwież kanał";
 theUILang.rssMenuDisable		= "Wyłącz kanał";
 theUILang.rssMenuEnable		= "Włącz kanał";
 theUILang.rssMenuEdit			= "Edytuj kanał";
 theUILang.rssMenuDelete		= "Usuń kanał";
 theUILang.rssDeletePrompt		= "Czy na pewno chcesz usunąć wybrany kanał?";
 theUILang.rssNewFilter 		= "Nowy filtr";
 theUILang.rssFilter			= "Filtr";
 theUILang.rssAddFilter 		= "Dodaj";
 theUILang.rssDelFilter 		= "Usuń";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "Ustawienia filtra";
 theUILang.rssIncorrectFilter		= "Filtr jest niepoprawny.";
 theUILang.foundedByFilter		= "Dopasowania";
 theUILang.rssExclude			= "Wyklucz";
 theUILang.rssStatusError		= "Błąd pobierania";
 theUILang.rssFeeds			= "Kanały";
 theUILang.rssCheckTitle		= "Sprawdź pole title";
 theUILang.rssCheckDescription		= "Sprawdź pole description";
 theUILang.rssCheckLink 		= "Sprawdź pole link";
 theUILang.rssMinInterval		= "Sprawdzaj co";
 theUILang.rssIntervalAlways		= "(zawsze)";
 theUILang.rssIntervalOnce		= "(tylko raz)";
 theUILang.rssInterval12h		= "12 godzin";
 theUILang.rssInterval1d		= "1 dzień";
 theUILang.rssInterval2d		= "2 dni";
 theUILang.rssInterval3d		= "3 dni";
 theUILang.rssInterval4d		= "4 dni";
 theUILang.rssInterval6d		= "6 dni";
 theUILang.rssInterval1w		= "1 tydzień";
 theUILang.rssInterval2w		= "2 tygodnie";
 theUILang.rssInterval3w		= "3 tygodnie";
 theUILang.rssInterval1m		= "1 miesiąc";
 theUILang.rssClearFilter		= "Zresetuj";
 theUILang.rssMarkAs			= "Oznacz jako";
 theUILang.rssAsLoaded			= "Pobrany";
 theUILang.rssAsUnloaded		= "Nie pobrany";
 theUILang.addRSSGroup			= "Dodaj grupę";
 theUILang.editRSSGroup 		= "Edytuj grupę";
 theUILang.addRSSGroupContent		= "Zawartość";
 theUILang.rssMenuGroupDisable		= "Wyłącz grupę";
 theUILang.rssMenuGroupRefresh		= "Odśwież grupę";
 theUILang.rssMenuGroupEnable		= "Włącz grupę";
 theUILang.rssMenuGroupEdit		= "Edytuj grupę";
 theUILang.rssMenuGroupDelete		= "Usuń grupę";
 theUILang.rssMenuGroupContentsDelete	= "Usuń zawartość";
 theUILang.rssDeleteGroupPrompt 	= "Czy na pewno chcesz usunąć wybraną grupę?";
 theUILang.rssDeleteGroupContentsPrompt = "Czy na pewno chcesz usunąć wybraną grupę wraz z całą zawartością?";
 theUILang.rssAllFiters 		= "Wszystkie filtry";
 theUILang.rssUpdateInterval 		= "Aktualizuj co";
 theUILang.Directories			= "Katalogi";
 theUILang.Labels			= "Etykiety";

thePlugins.get("rss").langLoaded();

==> rutorrent-4.3.6.tar.gz: ruTorrent-4.3.6/plugins/rss/lang/pl.js <==
﻿/*
 * PLUGIN RSS
 *
 * Polish language file.
 *
 * Author: Dare (piczok@gmail.com)
 */

 theUILang.addRSS			= "Dodaj kanał";
 theUILang.feedURL			= "Adres kanału";
 theUILang.alias			= "Nazwa";
 theUILang.rssAuto			= "Automatycznie pobieraj elementy publikowane na kanale";
 theUILang.allFeeds			= "Wszystkie";
 theUILang.incorrectURL			= "Proszę, podaj poprawny adres kanału.";
 theUILang.cantFetchRSS			= "Błąd wczytywania kanału.";
 theUILang.rssAlreadyExist		= "Kanał już istnieje.";
 theUILang.rssDontExist			= "Kanał nie istnieje.";
 theUILang.rssCantLoadTorrent		= "Błąd pobierania torrenta.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Pobrany";
 theUILang.rssMenuLoad			= "Pobierz";
 theUILang.rssMenuOpen			= "Otwórz w przeglądarce";
 theUILang.rssMenuClearHistory		= "Wyczyść historię";
 theUILang.rssMenuAddToFilter		= "Dodaj do ulubionych";
 theUILang.rssMenuManager		= "Menedżer RSS";
 theUILang.rssMenuRefresh		= "Odśwież kanał";
 theUILang.rssMenuDisable		= "Wyłącz kanał";
 theUILang.rssMenuEnable		= "Włącz kanał";
 theUILang.rssMenuEdit			= "Edytuj kanał";
 theUILang.rssMenuDelete		= "Usuń kanał";
 theUILang.rssDeletePrompt		= "Czy na pewno chcesz usunąć wybrany kanał?";
 theUILang.rssNewFilter			= "Nowy filtr";
 theUILang.rssFilter			= "Filtr";
 theUILang.rssAddFilter			= "Dodaj";
 theUILang.rssDelFilter			= "Usuń";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "Ustawienia filtra";
 theUILang.rssIncorrectFilter		= "Filtr jest niepoprawny.";
 theUILang.foundedByFilter		= "Dopasowania";
 theUILang.rssExclude			= "Wyklucz";
 theUILang.rssStatusError		= "Błąd pobierania";
 theUILang.rssFeeds			= "Kanały";
 theUILang.rssCheckTitle		= "Sprawdź pole title";
 theUILang.rssCheckDescription		= "Sprawdź pole description";
 theUILang.rssCheckLink			= "Sprawdź pole link";
 theUILang.rssMinInterval		= "Sprawdzaj co";
 theUILang.rssIntervalAlways		= "(zawsze)";
 theUILang.rssIntervalOnce		= "(tylko raz)";
 theUILang.rssInterval12h		= "12 godzin";
 theUILang.rssInterval1d		= "1 dzień";
 theUILang.rssInterval2d		= "2 dni";
 theUILang.rssInterval3d		= "3 dni";
 theUILang.rssInterval4d		= "4 dni";
 theUILang.rssInterval6d		= "6 dni";
 theUILang.rssInterval1w		= "1 tydzień";
 theUILang.rssInterval2w		= "2 tygodnie";
 theUILang.rssInterval3w		= "3 tygodnie";
 theUILang.rssInterval1m		= "1 miesiąc";
 theUILang.rssClearFilter		= "Zresetuj";
 theUILang.rssMarkAs			= "Oznacz jako";
 theUILang.rssAsLoaded			= "Pobrany";
 theUILang.rssAsUnloaded		= "Nie pobrany";
 theUILang.addRSSGroup			= "Dodaj grupę";
 theUILang.editRSSGroup			= "Edytuj grupę";
 theUILang.addRSSGroupContent		= "Zawartość";
 theUILang.rssMenuGroupDisable		= "Wyłącz grupę";
 theUILang.rssMenuGroupRefresh		= "Odśwież grupę";
 theUILang.rssMenuGroupEnable		= "Włącz grupę";
 theUILang.rssMenuGroupEdit		= "Edytuj grupę";
 theUILang.rssMenuGroupDelete		= "Usuń grupę";
 theUILang.rssMenuGroupContentsDelete	= "Usuń zawartość";
 theUILang.rssDeleteGroupPrompt		= "Czy na pewno chcesz usunąć wybraną grupę?";
 theUILang.rssDeleteGroupContentsPrompt	= "Czy na pewno chcesz usunąć wybraną grupę wraz z całą zawartością?";
 theUILang.rssAllFiters			= "Wszystkie filtry";
 theUILang.rssUpdateInterval		= "Aktualizuj co";
 theUILang.rssShowErrorsDelayed		= "Delay RSS error notification until the log tab or RSS feed is visible";
 theUILang.Directories			= "Katalogi";
 theUILang.Labels			= "Etykiety";

thePlugins.get("rss").langLoaded();
